@@ -6,7 +6,7 @@ use EV ();
 use Carp ();
 use Socket ();
 
-our $VERSION = '1.506_03';
+our $VERSION = '1.506_04';
 
 require Feersum::Connection;
 require Feersum::Connection::Handle;
@@ -47,13 +47,13 @@ sub use_socket {
         # Raw socket (e.g., from Runner with SO_REUSEPORT) - use getsockname
         my $sockaddr = getsockname($sock);
         if ($sockaddr) {
-            my $family = Socket::sockaddr_family($sockaddr);
-            if ($family == Socket::AF_INET()) {
+            my $family = eval { Socket::sockaddr_family($sockaddr) };
+            if (defined $family && $family == Socket::AF_INET()) {
                 (my $packed_port, my $packed_addr) = Socket::sockaddr_in($sockaddr);
                 $host = Socket::inet_ntoa($packed_addr) || 'localhost';
                 # Use defined check - port 0 is valid (OS-assigned dynamic port)
                 $port = defined($packed_port) ? $packed_port : 80;
-            } elsif (eval { Socket::AF_INET6() } && $family == Socket::AF_INET6()) {
+            } elsif (defined $family && eval { Socket::AF_INET6() } && $family == Socket::AF_INET6()) {
                 (my $packed_port, my $packed_addr) = Socket::sockaddr_in6($sockaddr);
                 $host = Socket::inet_ntop(Socket::AF_INET6(), $packed_addr) || 'localhost';
                 # Use defined check - port 0 is valid (OS-assigned dynamic port)
@@ -149,9 +149,8 @@ L<feersum>, L<Feersum::Runner> or L<Plack::Handler::Feersum> for details).
 
 There are two handler interfaces for Feersum: The PSGI handler interface and
 the "Feersum-native" handler interface.  The PSGI handler interface is fully
-PSGI 1.03 compatible and supports C<psgi.streaming>. The
-C<psgix.input.buffered> and C<psgix.io> features of PSGI 1.1 are also
-supported.  The Feersum-native handler interface is "inspired by" PSGI, but
+PSGI 1.1 compatible, supporting C<psgi.streaming>, C<psgix.input.buffered>,
+and C<psgix.io>.  The Feersum-native handler interface is "inspired by" PSGI, but
 does some things differently for speed.
 
 Feersum will use "Transfer-Encoding: chunked" for HTTP/1.1 clients and
